==> core-0.0.12-sources.jar: de/quantummaid/usecasemaid/sideeffects/collector/ListSideEffectsCollector.java <==
/*
 * Copyright (c) 2020 Richard Hauswald - https://quantummaid.de/.
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package de.quantummaid.usecasemaid.sideeffects.collector;

import de.quantummaid.reflectmaid.GenericType;
import lombok.AccessLevel;
import lombok.EqualsAndHashCode;
import lombok.RequiredArgsConstructor;
import lombok.ToString;

import java.util.ArrayList;
import java.util.List;

import static de.quantummaid.reflectmaid.GenericType.genericType;

@ToString
@EqualsAndHashCode
@RequiredArgsConstructor(access = AccessLevel.PRIVATE)
public final class ListSideEffectsCollector<S> implements SideEffectsCollector<S, List<S>> {
    private final GenericType<S> sideEffectsType;
    private final GenericType<List<S>> collectorType;

    @SuppressWarnings("unchecked")
    public static <S> ListSideEffectsCollector<S> sideEffectsCollector(final GenericType<S> sideEffectType) {
        final GenericType<List<S>> collectorType = (GenericType<List<S>>) (Object) genericType(List.class, sideEffectType);
        return new ListSideEffectsCollector<>(sideEffectType, collectorType);
    }

    @Override
    public GenericType<List<S>> collectorType() {
        return collectorType;
    }

    @Override
    public List<S> createCollectorInstance() {
        return new ArrayList<>();
    }

    @Override
    public List<S> unpackSideEffects(final List<S> collector) {
        return collector;
    }
}

==> core-0.0.34-sources.jar: de/quantummaid/usecasemaid/sideeffects/collector/ListSideEffectsCollector.java <==
/*
 * Copyright (c) 2020 Richard Hauswald - https://quantummaid.de/.
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package de.quantummaid.usecasemaid.sideeffects.collector;

import de.quantummaid.reflectmaid.GenericType;
import lombok.AccessLevel;
import lombok.EqualsAndHashCode;
import lombok.RequiredArgsConstructor;
import lombok.ToString;

import java.util.ArrayList;
import java.util.List;

import static de.quantummaid.reflectmaid.GenericType.genericType;

@ToString
@EqualsAndHashCode
@RequiredArgsConstructor(access = AccessLevel.PRIVATE)
public final class ListSideEffectsCollector<S> implements SideEffectsCollector<S, List<S>> {
    private final GenericType<S> sideEffectsType;
    private final GenericType<List<S>> collectorType;

    public static <S> ListSideEffectsCollector<S> sideEffectsCollector(final GenericType<S> sideEffectType) {
        final GenericType<List<S>> collectorType = genericType(List.class, List.of(sideEffectType));
        return new ListSideEffectsCollector<>(sideEffectType, collectorType);
    }

    @Override
    public GenericType<List<S>> collectorType() {
        return collectorType;
    }

    @Override
    public List<S> createCollectorInstance() {
        return new ArrayList<>();
    }

    @Override
    public List<S> unpackSideEffects(final List<S> collector) {
        return collector;
    }
}
